@@ -35,7 +35,7 @@ from mercurial import hg
 from mercurial.error import RepoLookupError
 
 
-DEBUG_GITIFYHG = os.environ.get("DEBUG_GITIFYHG", "").lower() == "on"
+DEBUG_GITIFYHG = os.environ.get("DEBUG_GITIFYHG") != None
 
 
 def log(msg, level="DEBUG"):
@@ -307,10 +307,15 @@ class HGRemote(object):
         else:
             # If there is no bookmark for head, mock one
             head = current_branch
-            node = self.repo['.'] or self.repo['tip']
+            node = self.repo['.']
+            # I think this means an initial clone occured and we haven't
+            # hg updated yet in the local clone
             if not node:
-                output()
-                return
+                if 'default' in self.repo:
+                    node = self.repo['default']
+                else:  # empty repository or head is at 0 commit
+                    output()
+                    return
             head = head if head != 'default' else 'master'
             self.bookmarks[head] = node
 
@@ -322,7 +327,7 @@ class HGRemote(object):
 
         # update the named branch references
         for branch in self.repo.branchmap():
-            heads = self.repo.branchheads(branch)
+            heads = self.repo.branchheads(branch, closed=True)
             if heads:
                 self.branches[branch] = heads
 
@@ -374,7 +379,7 @@ class HGImporter(object):
         while self.parser.line.startswith('import'):
             ref = self.parser.line.split()[1]
 
-            if (ref == 'HEAD'):
+            if ref == 'HEAD':
                 self.process_ref(
                     self.hgremote.headnode[0],
                     'bookmarks',
@@ -605,7 +610,7 @@ class GitExporter(object):
         tip = self.repo[tip].rev()
         log("%r %r" % (git_marked_tip, tip))
         if git_marked_tip < tip:
-            output("error %s already exists\n" % ref)
+            output("error %s non-fast forward\n" % ref)
             sys.exit(1)
 
         commit_mark = self.parser.read_mark()
