@@ -76,18 +76,21 @@ def test_clone_linear_branch(git_dir, hg_repo):
 
     assert git_repo.exists()
     assert git_repo.joinpath('test_file').exists()
-    with git_repo.joinpath('test_file').open() as file:
-        assert file.read() == "a\nb"
-
-    assert_git_count(2)
-    assert_git_messages(['b', 'a'])
-    print sh.git.branch(remote=True)
+    assert_git_count(1)
+    assert_git_messages(['a'])
     assert sh.git.branch(remote=True).stdout == """  origin/HEAD -> origin/master
   origin/branches/default
   origin/branches/featurebranch
   origin/master
 """
 
+    sh.git.checkout('branches/featurebranch')
+
+    with git_repo.joinpath('test_file').open() as file:
+        assert file.read() == "a\nb"
+    assert_git_count(2)
+    assert_git_messages(['b', 'a'])
+
 
 def test_clone_simple_branch(git_dir, hg_repo):
     '''Two divergent branches'''
@@ -115,18 +118,21 @@ def test_clone_branch_with_spaces(git_dir, hg_repo):
 
     assert git_repo.exists()
     assert git_repo.joinpath('test_file').exists()
-    with git_repo.joinpath('test_file').open() as file:
-        assert file.read() == "a\nb"
-
-    assert_git_count(2)
-    assert_git_messages(['b', 'a'])
-    print sh.git.branch(remote=True)
+    assert_git_count(1)
+    assert_git_messages(['a'])
     assert sh.git.branch(remote=True).stdout == """  origin/HEAD -> origin/master
   origin/branches/default
   origin/branches/feature___branch
   origin/master
 """
 
+    sh.git.checkout('branches/feature___branch')
+
+    with git_repo.joinpath('test_file').open() as file:
+        assert file.read() == "a\nb"
+    assert_git_count(2)
+    assert_git_messages(['b', 'a'])
+
 
 def test_clone_merged_branch(git_dir, hg_repo):
     sh.cd(hg_repo)
@@ -306,10 +312,6 @@ def test_clone_tag_with_spaces(git_dir, hg_repo):
     sh.hg.tag("THIS IS TAGGED")
     make_hg_commit("c")
 
-    # TODO: hg allows tags with spaces, but git thinks that is an attrocious
-    # thing to do. We need to either escape spaces in the tag in some way
-    # or discard the tag with an appropriate warning message, not fail on the
-    # clone.
     clone_repo(git_dir, hg_repo)
 
     result = sh.git.tag()
@@ -422,3 +424,27 @@ def test_sym_link(git_dir, hg_repo):
     sh.hg.update()
     assert p('second_link').islink()
 
+
+def test_clone_close_branch(git_dir, hg_repo):
+    sh.cd(hg_repo)
+    sh.hg.branch('feature')
+    make_hg_commit("b", "b")
+    sh.hg.update('default')
+    make_hg_commit("c")
+    sh.hg.update('feature')
+    write_to_test_file("d", "b")
+    sh.hg.commit('--close-branch', message="d")
+
+    git_repo = clone_repo(git_dir, hg_repo)
+    sh.cd(git_repo)
+    # TODO: Perhaps it should make an archived tag instead of a branch...
+    print sh.git.branch(remote=True)
+    assert sh.git.branch(remote=True).stdout == """  origin/HEAD -> origin/master
+  origin/branches/default
+  origin/branches/feature
+  origin/master
+"""
+
+    assert_git_messages(['c', 'a'])
+    sh.git.checkout("origin/branches/feature")
+    assert_git_messages(['d', 'b', 'a'])
